@@ -1,20 +1,9 @@
 package Template::ShowStartStop;
-
-use warnings;
+BEGIN {
+  $Template::ShowStartStop::VERSION = '0.06';
+}
 use strict;
-
-=head1 NAME
-
-Template::ShowStartStop - Display where template's start and stop
-
-=head1 VERSION
-
-Version 0.05
-
-=cut
-
-our $VERSION = '0.05';
-
+use warnings;
 use parent qw( Template::Context );
 
 my $sub = qw(process);
@@ -46,16 +35,20 @@ my $wrapped = sub {
 { no strict 'refs'; *{$sub} = $wrapped; }
 
 1;
-__END__
+
+
+=pod
+
+=head1 NAME
+
+Template::ShowStartStop - Display where template's start and stop
+
+=head1 VERSION
+
+version 0.06
 
 =head1 SYNOPSIS
 
-Template::ShowStartStop provides inline comments througout your code where
-each template stops and starts.  It's an overridden version of L<Template::Context>
-that wraps the C<process()> method.
-
-Using Template::ShowStartStop is simple.
-
 	use Template::ShowStartStop;
 
 	my %config = ( # Whatever your config is
@@ -64,12 +57,17 @@ Using Template::ShowStartStop is simple.
 		COMPILE_DIR	 => '/tmp/tt',
 	);
 
-	if ( $development_mode ) {
-		$config{ CONTEXT } = Template::ShowStartStop->new( %config );
-	}
+	$config{ CONTEXT } = Template::ShowStartStop->new( %config );
 
 	my $template = Template->new( \%config );
 
+=head1 DESCRIPTION
+
+Template::ShowStartStop provides inline comments througout your code where
+each template stops and starts.  It's an overridden version of L<Template::Context>
+that wraps the C<process()> method.
+
+Using Template::ShowStartStop is simple.
 Now when you process templates, HTML comments will get embedded in your
 output, which you can easily grep for.  The nesting level is also shown.
 
@@ -80,10 +78,6 @@ output, which you can easily grep for.  The nesting level is also shown.
 
 	<!-- STOP:  include mainmenu/footer.tt -->
 
-=head1 AUTHOR
-
-Caleb Cushing, C<< <xenoterracide@gmail.com> >>
-
 =head1 BUGS
 
 Please report any bugs or feature requests on 
@@ -98,17 +92,23 @@ Randal Schwartz,
 Bill Moseley,
 and to Gavin Estey for the original Template::Timer code that this is based on.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-This library is free software; you can redistribute it and/or modify
-it under the terms of either the GNU Public License v3, or the Artistic
-License 2.0.
+  Caleb Cushing <xenoterracide@gmail.com>
 
-	* http://www.gnu.org/copyleft/gpl.html
+=head1 COPYRIGHT AND LICENSE
 
-	* http://www.opensource.org/licenses/artistic-license-2.0.php
+This software is copyright (c) 2010 by Caleb Cushing.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+# ABSTRACT: Display where template's start and stop
+
 # notes from an IRC conversation on how to improve this module
 [Tuesday 02 March 2010] [04:26:51 pm] <tm604>   xenoterracide: you can get rid
 of foreach, since you only wrap one method, also drop my $super = ...;, remove
